@@ -1,7 +1,8 @@
 from transformers import BertConfig, BertTokenizer
 
 from ai_transformersx import *
-from ai_transformersx.examples import start_example_task, _build_arguments
+from ai_transformersx.examples import ExampleManagement, ExampleTaskBase
+from ai_transformersx.examples.main import manager
 
 
 class TestTransformersxTask:
@@ -17,11 +18,12 @@ class TestTransformersxTask:
         assert isinstance(taskModel.tokenizer, (BertTokenizer))
 
     def test_parse_task_arguments(self):
-        argument_objs = _build_arguments()
+        manager = ExampleManagement()
+        argument_objs = manager._build_arguments()
         args = ["news", "--action=train", "--processor-args.data-dir=/test/test"]
         task_name, arguments = ComplexArguments(argument_objs).parse(args)
         assert task_name == "news"
         assert arguments.processor_args.data_dir == "/test/test"
 
     def test_start_example_task(self):
-        start_example_task(["news", "--action=train", "--processor-args.data-dir=/test/test"], True)
+        manager.start_example_task(["news", "--action=train", "--processor-args.data-dir=/test/test"], True)
